============
Installation
============

At the command line::

    $ easy_install storage_provisioner

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv storage_provisioner
    $ pip install storage_provisioner
